/* SofChat (Web Chat program SHM version)      */
/* Copyright(c) 1996-1998 Y.YONEYAMA           */
/*                                             */
/* sofchat.h                                   */

#ifndef _SOFCHAT_H_
#define _SOFCHAT_H_

#include <sys/types.h>

#define NAME_LEN       21
#define PASS_LEN       11
#define ADDR_LEN       81
#define HADDR_LEN      41
#define LABEL_LEN      81
#define AGENT_LEN     128
#define COLOR_LEN      21
#define MEMO_SIZE     256
#define MSG_SIZE     1024

typedef unsigned long IP;

typedef enum {
  m_init,
  m_entry,
  m_input,
  m_chattext,
  m_bbs,
  m_reset,
  m_logout,
  m_customize,
  m_debug,
  m_doc
} CHATMODE;


#define SET_FLAG(x, f)    x |= (f)
#define RESET_FLAG(x, f)  x &= ~(f)
#define IS_FLAG(x, f)     (((x) & (f)) == (f))

/* USER flags */
#define USER_ITALIC       (1)
#define USER_BOLD         (1<<1)
#define USER_SKIPTITLE    (1<<2)
#define USER_REFUSE       (1<<3)
#define USER_TEXTHR       (1<<4)
#define USER_CRASH        (1<<5)

typedef struct {
  char name[NAME_LEN];          /* Handle name */
  char cookiename[NAME_LEN];    /* Handle name (cookie)*/
  char password[PASS_LEN];      /* password */
  char address[ADDR_LEN];       /* mail address or http URL */
  char referer[ADDR_LEN];       /* HTTP_REFERER */
  char haddress[HADDR_LEN];     /* host address */
  char agent[AGENT_LEN];        /* name of browser */
  char memo[MEMO_SIZE];         /* messages */
  char namecolor[COLOR_LEN];    /* name color */
  char textcolor[COLOR_LEN];    /* text color */
  IP   haddressip;              /* host address (IP) */
  time_t logintime;             /* last login time */
  time_t atime;                 /* last atach time */
  time_t ctime;                 /* chat time */
  time_t btime;                 /* bbs last access time */
  time_t altime;                /* last alerted time */
  int  login;                   /* login status */
  int  count;                   /* speech count */
  int  sendcount;               /* alert send count */
  int  recvcount;               /* alert receive count */
  int  permit;                  /* permission */
  int  refresh;                 /* refresh time */
  int  maxlines;                /* max log lines */
  int  room;                    /* chat room */
  int  flags;                   /* other flags */
  int  mid;                     /* modified id */
} USERINFO;

typedef struct {
  time_t atime;
  IP     address;
  char   name[NAME_LEN];        /* Handle name */
  int  mid;                     /* modified id */
} HOSTINFO;


/* TEXT flags */
#define TEXT_ITALIC       (1)

#define SECURE_BBS        (1)

typedef struct {
  time_t atime;                 /* access time */
  int lang;                     /* language */
  char namecolor[COLOR_LEN];    /* name color */
  char textcolor[COLOR_LEN];    /* text color */
  char name[NAME_LEN];          /* Handle name */
  char message[MSG_SIZE];       /* message */
  int  room;                    /* room no */
  int  flags;                   /* other flags */
} TEXT;

typedef struct {
  char label_ja[LABEL_LEN];
  char label_en[LABEL_LEN];
  char url[ADDR_LEN];
} LINK;

/* os type */
#define OS_UNKNOWN       (0)
#define OS_WINDOWS       (1)
#define OS_MAC           (2)
#define OS_IMODE         (3)
#define OS_VIMODE        (4)
#define OS_JPHONE        (5)

#define isWINDOWS(x) ((x) == OS_WINDOWS)
#define isMAC(x) ((x) == OS_MAC)
#define isIMODE(x) ((x) == OS_IMODE || (x) == OS_VIMODE || (x) == OS_JPHONE)

/* MACROS */

#define strncpy scstrncpy  /* utils.c */

#endif /* _SOFCHAT_H_ */
